@@ -1,6 +1,6 @@
 -- date_before()
 function date_before(days)
-	checktype_aux(days, 'number')
+	check_type(days, 'number')
 
 	return os.date("%d-%b-%Y", os.time() - days * 60 * 60 * 24)
 end
@@ -22,8 +22,8 @@ end
 
 -- pipe_to()
 function pipe_to(command, data)
-	checktype_aux(command, 'string')
-	checktype_aux(data, 'string')
+	check_type(command, 'string')
+	check_type(data, 'string')
 
 	f = ifsys.popen(command, "w")
 
@@ -34,7 +34,7 @@ end
 
 -- pipe_from()
 function pipe_from(command)
-	checktype_aux(command, 'string')
+	check_type(command, 'string')
 
 	f = ifsys.popen(command, "r")
 
@@ -53,8 +53,8 @@ end
 
 -- daemon_mode()
 function daemon_mode(interval, commands)
-	checktype_aux(interval, 'number')
-	checktype_aux(commands, 'function')
+	check_type(interval, 'number')
+	check_type(commands, 'function')
 
 	ifsys.daemon()
 
