@@ -8,7 +8,7 @@
  * Initialize buffer.
  */
 void
-buffer_init(buffer_t * buf, size_t n)
+buffer_init(buffer * buf, size_t n)
 {
 
 	buf->data = (char *)xmalloc(n + 1);
@@ -21,7 +21,7 @@ buffer_init(buffer_t * buf, size_t n)
  * Free allocated memory of buffer.
  */
 void
-buffer_free(buffer_t * buf)
+buffer_free(buffer * buf)
 {
 	if (!buf->data)
 		return;
@@ -35,7 +35,7 @@ buffer_free(buffer_t * buf)
  * Reset buffer.
  */
 void
-buffer_reset(buffer_t * buf)
+buffer_reset(buffer * buf)
 {
 
 	*buf->data = '\0';
@@ -47,7 +47,7 @@ buffer_reset(buffer_t * buf)
  * needed.
  */
 void
-buffer_check(buffer_t * buf, size_t n)
+buffer_check(buffer * buf, size_t n)
 {
 
 	while (n > buf->size) {
