@@ -9,14 +9,14 @@
 typedef struct buffer {
 	char *data;
 	size_t size;
-} buffer_t;
+} buffer;
 
 
 /*	buffer.c	*/
-void buffer_init(buffer_t * buf, size_t n);
-void buffer_free(buffer_t * buf);
-void buffer_reset(buffer_t * buf);
-void buffer_check(buffer_t * buf, size_t n);
+void buffer_init(buffer * buf, size_t n);
+void buffer_free(buffer * buf);
+void buffer_reset(buffer * buf);
+void buffer_check(buffer * buf, size_t n);
 
 
 #endif				/* BUFFER_H */
