@@ -11,7 +11,7 @@
 #include "pathnames.h"
 
 
-extern options_t opts;
+extern environment env;
 
 
 /*
@@ -20,15 +20,26 @@ extern options_t opts;
 int
 create_homedir(void)
 {
-	char hd[PATH_MAX];
+	int n;
+	char b;
+	char *hd;
 
-	snprintf(hd, PATH_MAX, "%s/%s", opts.home, PATHNAME_HOME);
+	n = snprintf(&b, 1, "%s/%s", env.home, PATHNAME_HOME);
+
+	if (env.pathmax != -1 && n > env.pathmax)
+		fatal(ERROR_PATHNAME,
+		    "pathname limit %ld exceeded: %d\n", env.pathmax, n);
+
+	hd = (char *)xmalloc((n + 1) * sizeof(char));
+	snprintf(hd, n + 1, "%s/%s", env.home, PATHNAME_HOME);
 
 	if (!exists_dir(hd)) {
 		if (mkdir(hd, S_IRUSR | S_IWUSR | S_IXUSR))
 			error("could not create directory %s; %s\n", hd,
 			    strerror(errno));
 	}
+	xfree(hd);
+
 	return 0;
 }
 
@@ -94,3 +105,25 @@ create_file(char *fname, mode_t mode)
 	}
 	return 0;
 }
+
+
+/*
+ * Get the system's maximum number of bytes in a pathname.
+ */
+int
+get_pathmax(void)
+{
+	int n;
+
+	errno = 0;
+
+	n = pathconf("/", _PC_PATH_MAX);
+
+	if (n == -1 && errno != 0) {
+		error("getting PATH_MAX limit; %s\n", strerror(errno));
+		return -1;
+	}
+	env.pathmax = n;
+
+	return 0;
+}
