@@ -12,12 +12,12 @@ extern struct sessionhead sessions;
 /*
  * Allocate memory for a new session and add it to the sessions linked list.
  */
-session_t *
+session *
 session_new(void)
 {
-	session_t *s;
+	session *s;
 
-	s = (session_t *) xmalloc(sizeof(session_t));
+	s = (session *) xmalloc(sizeof(session));
 
 	session_init(s);
 
@@ -31,7 +31,7 @@ session_new(void)
  * Set session variables to safe values.
  */
 void
-session_init(session_t * ssn)
+session_init(session * ssn)
 {
 	ssn->server = NULL;
 	ssn->username = NULL;
@@ -50,7 +50,7 @@ session_init(session_t * ssn)
  * Remove session from sessions linked list.
  */
 void
-session_destroy(session_t * ssn)
+session_destroy(session * ssn)
 {
 	XLIST_REMOVE(ssn, links);
 
@@ -62,7 +62,7 @@ session_destroy(session_t * ssn)
  * Free session allocated memory.
  */
 void
-session_free(session_t * ssn)
+session_free(session * ssn)
 {
 
 	if (ssn->server)
@@ -78,10 +78,10 @@ session_free(session_t * ssn)
 /*
  * Based on the specified socket, find an active IMAP session.
  */
-session_t *
+session *
 session_find(const char *serv, const char *user)
 {
-	session_t *s;
+	session *s;
 
 	XLIST_FOREACH(s, &sessions, links)
 	    if (!strncmp(s->server, serv, strlen(serv)) &&
