@@ -28,15 +28,15 @@ typedef struct session {
 		char delim;	/* Namespace delimiter. */
 	} ns;
 	 XLIST_ENTRY(session) links;
-} session_t;
+} session;
 
 
 /*	session.c	*/
-session_t *session_new(void);
-void session_init(session_t * ssn);
-void session_destroy(session_t * ssn);
-void session_free(session_t * ssn);
-session_t *session_find(const char *server, const char *user);
+session *session_new(void);
+void session_init(session * ssn);
+void session_destroy(session * ssn);
+void session_free(session * ssn);
+session *session_find(const char *server, const char *user);
 
 
 #endif				/* SESSION_H */
